Learn R Programming

PandemicLP (version 1.3.0)

PandemicLP: PandemicLP: Modeling Pandemic Data

Description

Arguments

Details

The PandemicLP package provides five main functions that enable the user to make short and long-term predictions of epidemic and pandemic count data.

This package is a result of the joint work by professors and graduate students from the Statistics Department at Universidade Federal de Minas Gerais (UFMG). It originated as a challenge in a graduate course after the suspension of classes due to Covid-19.

Theoretical foundation and more information about the project can be found in est.ufmg.br/covidlp/home/en

Examples

Run this code
# NOT RUN {
data = load_covid("Brazil")
plot(data)
estim = pandemic_model(data)
pred = posterior_predict(estim)
stats = pandemic_stats(pred)
plot(pred)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab