density.pandemicEstimated: Draw estimated density of the parameters for the pandemic model
Description
Uses stan's stan_dens function to draw the marginal posterior for the relevant parameters of the estimated model.
Defined as a method for the stats::density generic function.
Usage
# S3 method for pandemicEstimated
density(x, waves = 1:x$n_waves, ...)