plottedPandemic objectsThe print method for a plottedPandemic S3 class object displays the single plot or both
separated by a prompt for the user.
# S3 method for plottedPandemic
print(x, ...)An object of S3 class plottedPandemic-objects.
Currently unused.
Returns x, invisibly.
The plots generated by plot.pandemicPredicted are displayed by this function
If only one of the plots has been generated via the argument term, then it is displayed
in the Viewer windows as an html object, produced by the plot_ly function.
If both long term and short term plots are requested, then the long term plot is displayed first
and a message prompts the user to display the next plot, namely the short term one.
posterior_predict.pandemicEstimated and plot.pandemicPredicted