Description Usage Arguments Value Source References See Also Examples
This function pulls Covid-19 data up to a certain date, for a specified country (and state, if country_name = "Brazil").
The output of this function is in the correct format to be used directly into the model adjustment function
pandemic_model included in this package.
The user must online for this function to work.
1 | load_covid(country_name, state_name, last_date)
|
country_name |
Character string specifying the country of interest.
Check |
state_name |
Optional character string specifying the state of interest - only brazilians states currently
available in the database. |
last_date |
Optional date, character or factor argument specifying the last date in the data. It should be in the YYYY-MM-DD or YYYY/MM/DD format.The default is the most recent date available in the database. |
A list with 3 items.
The first item is a data frame with the number of cumulative cases, new cases, cumulative deaths and new deaths associated with Covid-19 for each date, up to the last_date in the specified region.
The second item is a character string with the country name (and state name, if available).
The third item is a numeric object that contains the population size of the given region.
https://github.com/CSSEGISandData/COVID-19 https://github.com/covid19br/covid19br.github.io
CovidLPTeam, 2020. CovidLP: Short and Long-term Prediction for COVID-19. Departamento de Estatistica. UFMG, Brazil. URL: http://est.ufmg.br/covidlp/home/en/
country_list state_list pandemic_model
posterior_predict.pandemicEstimated plot.pandemicPredicted
1 2 3 4 | load_covid("Brazil","MG")
load_covid(country_name = "India", last_date = "2020-06-15")
load_covid("US")
load_covid(country_name = "italy")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.